Module message

Module message 

Structs

Message
Message is the wrapper around the entire payload to be sent to SendGrid’s API. Use MessageBuilder to properly construct this. The to_json method is available to turn this struct into the request body to send to SendGrid
MessageBuilder
A builder pattern type for constructing Message