pub struct AsmBuilder { /* private fields */ }Expand description
A builder pattern for constructing Asm
Make sure you call build() to consume the builder and retrieve the underyling Asm
Implementations
Sourceimpl AsmBuilder
impl AsmBuilder
Sourcepub fn new(group_id: i32) -> Self
pub fn new(group_id: i32) -> Self
Creates the builder. group_id is the only required paramteter which is associated
to the SendGrid group_id for Asm subscriptions
Examples
let builder = AsmBuilder::new(1);Sourcepub fn group_to_display(self, group: i32) -> Self
pub fn group_to_display(self, group: i32) -> Self
Adds a display group to the Asm
Examples
let builder = AsmBuilder::new(1)
.group_to_display(2)
.group_to_display(3);Auto Trait Implementations
impl Freeze for AsmBuilder
impl RefUnwindSafe for AsmBuilder
impl Send for AsmBuilder
impl Sync for AsmBuilder
impl Unpin for AsmBuilder
impl UnsafeUnpin for AsmBuilder
impl UnwindSafe for AsmBuilder